@if(Config::has('foundation.codes.addthis'))
    <div class="social-share">
        <h4>Share</h4>
        <div class="addthis_sharing_toolbox"></div>
    </div>
    @if (!isset($social_share_shown))
        <?php // This allows for including this file multiple times on a page, while the script will only be added once ?>
        <?php $__env->share('social_share_shown',true); ?>
        @section('body-end')
            @parent
            @if(setting_or_config('foundation.codes.analytics'))
                <script type="text/javascript">
                    var addthis_config = {
                        data_ga_property: '{{ setting_or_config('foundation.codes.analytics') }}',
                        data_ga_social : true
                    };
                </script>
            @endif
            <script type="text/javascript" src="//s7.addthis.com/js/300/addthis_widget.js#pubid={{ setting_or_config('foundation.codes.addthis') }}" async="async"></script>
        @stop
    @endif
@endif