<?php namespace Concore\Foundation\Models\Interfaces;

interface IdentifiableInterface {

	function getSnake();

	function getSnakePlural();

	function getHumanReadable();

	function getHumanReadablePlural();

	function getSlugged();

	function getSluggedPlural();

	function getUrl();

	function getShortUrl();

}