<?php

Route::get('/media-direct/image/{size}/{filename}', ['as' => 'image-direct', 'uses' => 'Concore\Foundation\Http\Controllers\MediaController@showImageDirect'])
    ->where('filename', '.*\..{3,4}');

Route::get('/media-direct/{type}/{filename}', ['as' => 'media-direct', 'uses' => 'Concore\Foundation\Http\Controllers\MediaController@showDirect'])
    ->where('filename', '.*\..{3,4}');

Route::get('/media/image/{size}/{filename}', ['as' => 'image', 'uses' => 'Concore\Foundation\Http\Controllers\MediaController@showImage'])
    ->where('filename', '.*\..{3,4}');

Route::get('/media/{type}/{filename}', ['as' => 'media', 'uses' => 'Concore\Foundation\Http\Controllers\MediaController@show'])
    ->where('filename', '.*\..{3,4}');

Route::get('/touch', function() {
    return csrf_token();
});