<?php

class FoundationRoutesTest extends TestCase
{

    /**
     * Check the response from the touch route
     *
     * @return void
     */
    public function testTouch()
    {
        $this->call('GET', '/touch');
        $this->assertRegExp('/^([a-zA-Z0-9]{40})$/', $this->response());
    }

}