@if(isset($in_maintenance_mode))
    <p class="alert alert-warning text-center"><strong>Warning:</strong> Application currently in maintenance mode, only visible to IPs: {{ setting_or_config('foundation.maintenance-mode-allowed-ips') }} (Your IP: {{ Request::getClientIp() }})</p>
@endif