Hello,<br />
<br />
Please click here to reset your password for {{ setting_or_config('foundation.site-name') }}: <a href="{{ url('password/reset/'.$token) }}">{{ url('password/reset/'.$token) }}</a><br />
<br />
Let me know if you're having any difficulty logging in.<br />
<br />
{!! $email_signature ?: '- ' . setting_or_config('foundation.site-name') !!}